@@ -10,7 +10,12 @@ the Twitter APIs, with a method to upload a media
 import asyncio
 import io
 import logging
-from concurrent.futures import CancelledError
+
+try:
+    from asyncio.exceptions import CancelledError
+except ImportError:  # pragma: no cover
+    from concurrent.futures import CancelledError
+
 from urllib.parse import urlparse
 
 import aiohttp
@@ -18,6 +23,7 @@ import aiohttp
 from . import data_processing, exceptions, general, oauth, utils
 from .api import APIPath, StreamingAPIPath
 from .commands import EventStreams, task
+from .exceptions import PeonyUnavailableMethod
 from .oauth import OAuth1Headers
 from .stream import StreamResponse
 
@@ -430,10 +436,10 @@ class BasePeonyClient(metaclass=MetaPeonyClient):
                     self.setup.cancel()
                     try:
                         await self.setup
-                    except:  # pragma: no cover
+                    except CancelledError:  # pragma: no cover
                         pass
 
-                tasks.append(cancel_setup())
+                tasks.append(self.loop.create_task(cancel_setup()))
 
         # close currently running tasks
         if self._gathered_tasks is not None:
@@ -441,15 +447,15 @@ class BasePeonyClient(metaclass=MetaPeonyClient):
                 self._gathered_tasks.cancel()
                 try:
                     await self._gathered_tasks
-                except:
+                except CancelledError:
                     pass
 
-            tasks.append(cancel_tasks())
+            tasks.append(self.loop.create_task(cancel_tasks()))
 
         # close the session only if it was created by peony
         if not self._user_session and self._session is not None:
             try:
-                tasks.append(self._session.close())
+                tasks.append(self.loop.create_task(self._session.close()))
             except (TypeError, AttributeError):
                 pass
 
@@ -479,30 +485,7 @@ class PeonyClient(BasePeonyClient):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
-        task = self.loop.create_task(self._get_twitter_configuration())
-        self._twitter_configuration = task
-        if isinstance(self.headers, oauth.OAuth1Headers):
-            self._user = self.loop.create_task(self._get_user())
-
-    async def _get_twitter_configuration(self):
-        """
-        create a ``twitter_configuration`` attribute with the response
-        of the endpoint
-        https://api.twitter.com/1.1/help/configuration.json
-        """
-        api = self['api', general.twitter_api_version,
-                   ".json", general.twitter_base_api_url]
-
-        if isinstance(self.headers, OAuth1Headers):
-            return await api.help.configuration.get()
-
-    @property
-    def twitter_configuration(self):
-        return self._twitter_configuration
-
-    @property
-    def user(self):
-        return self._user
+        self.user = self.loop.create_task(self._get_user())
 
     async def _get_user(self):
         """
@@ -512,31 +495,25 @@ class PeonyClient(BasePeonyClient):
         api = self['api', general.twitter_api_version,
                    ".json", general.twitter_base_api_url]
 
-        return await api.account.verify_credentials.get()
+        if isinstance(self.headers, oauth.OAuth1Headers):
+            return await api.account.verify_credentials.get()
+
+        raise PeonyUnavailableMethod("user attribute is only available with "
+                                     "OAuth 1 authentification.")
 
     def _get_close_tasks(self):
         tasks = super()._get_close_tasks()
 
-        if self.twitter_configuration.done():
-            async def cancel_twitter_configuration():
-                self.twitter_configuration.cancel()
-                try:
-                    await self.twitter_configuration
-                except:  # pragma: no cover
-                    pass
-
-            tasks.append(cancel_twitter_configuration())
-
-        if isinstance(self.user, asyncio.Future):
-            if self.user.done():
+        if isinstance(self.headers, OAuth1Headers):
+            if not self.user.done():
                 async def cancel_user():
                     self.user.cancel()
                     try:
                         await self.user
-                    except:  # pragma: no cover
+                    except CancelledError:  # pragma: no cover
                         pass
 
-                tasks.append(cancel_user())
+                tasks.append(self.loop.create_task(cancel_user()))
 
         return tasks
 
@@ -598,18 +575,14 @@ class PeonyClient(BasePeonyClient):
         i = 0
 
         while chunk:
+            req = self.upload.media.upload.post(command="APPEND",
+                                                media_id=media_id,
+                                                media=chunk,
+                                                segment_index=i)
             if is_coro:
-                req = self.upload.media.upload.post(command="APPEND",
-                                                    media_id=media_id,
-                                                    media=chunk,
-                                                    segment_index=i)
                 chunk, _ = await asyncio.gather(media.read(chunk_size), req)
             else:
-                await self.upload.media.upload.post(command="APPEND",
-                                                    media_id=media_id,
-                                                    media=chunk,
-                                                    segment_index=i)
-
+                await req
                 chunk = media.read(chunk_size)
 
             i += 1
@@ -640,24 +613,14 @@ class PeonyClient(BasePeonyClient):
 
         return response
 
-    async def _size_test(self, size, size_limit):
-        if size_limit is None:
-            try:
-                twitter_config = await self.twitter_configuration
-                size_limit = twitter_config['photo_size_limit']
-            except (KeyError, TypeError):
-                return False
-
-        return size > size_limit
-
     async def upload_media(self, file_,
                            media_type=None,
                            media_category=None,
                            chunked=None,
-                           size_limit=None,
+                           size_limit=3 * (1024**2),
                            **params):
         """
-            upload a media on twitter
+            upload a media file on twitter
 
         Parameters
         ----------
@@ -698,7 +661,7 @@ class PeonyClient(BasePeonyClient):
         if chunked is not None:
             size_test = False
         else:
-            size_test = await self._size_test(media_size, size_limit)
+            size_test = media_size > size_limit
 
         if isinstance(media, aiohttp.ClientResponse):
             # send the content of the response
